@echo off
@REM BEGIN COPYRIGHT
@REM *************************************************************************
@REM
@REM  Licensed Materials - Property of IBM
@REM  5725-C94, 5725-C95, 5725-C96
@REM  (C) Copyright IBM Corporation 2005, 2014. All Rights Reserved.
@REM  US Government Users Restricted Rights- Use, duplication or disclosure
@REM  restricted by GSA ADP Schedule Contract with IBM Corp.
@REM
@REM *************************************************************************
@REM END COPYRIGHT

setlocal

REM initialize
SET RC=0
SET SERVERNAME=
SET NODENAME=
SET CLUSTERNAME=

:PARAM_LOOP
REM No more parameters to process
IF [%1]==[] GOTO VERIFY_INPUTS
IF [%1]==[-serverName] SET SERVERNAME=%2%& SHIFT & SHIFT & GOTO PARAM_LOOP
IF [%1]==[-nodeName] SET NODENAME=%2%& SHIFT & SHIFT & GOTO PARAM_LOOP
IF [%1]==[-clusterName] SET CLUSTERNAME=%2%& SHIFT & SHIFT & GOTO PARAM_LOOP
IF [%1]==[-default] SET DEFAULT_ACTION=%2%& SHIFT & SHIFT & GOTO PARAM_LOOP
IF [%1]==[-help] SET RC=0 & GOTO PRINT_USAGE
IF [%1]==[-h] SET RC=0 & GOTO PRINT_USAGE
IF [%1]==[-?] SET RC=0 & GOTO PRINT_USAGE
SHIFT
GOTO PARAM_LOOP

:VERIFY_INPUTS
ECHO.
ECHO WAS_HOME is %WAS_HOME%
ECHO USER_INSTALL_ROOT is %USER_INSTALL_ROOT%
ECHO.
IF ["%WAS_HOME%"]==[""] SET RC=1 & echo WAS_HOME was not found. Run command from profile\bin directory or run setupCmdLine.bat prior to this command. & GOTO END
IF ["%USER_INSTALL_ROOT%"]==[""] SET RC=1 & echo -profilePath is required. & GOTO PRINT_USAGE
IF NOT [%DEFAULT_ACTION%] == [] GOTO DO_DEFAULT_ACTION
IF NOT [%CLUSTERNAME%] == [] GOTO CHECKNODE_EMPTY
IF [%NODENAME%]==[] GOTO CHECKSERVER_EMPTY
IF [%SERVERNAME%]==[] GOTO PRINT_USAGE

GOTO SERVER_SPECIFIC
SET RC=1 & GOTO PRINT_USAGE

REM Check for both server and node names to be empty
:CHECKNODE_EMPTY
IF NOT [%NODENAME%] == [] SET RC=1 & echo nodeName cannot be specified with clusterName. & GOTO PRINT_USAGE
IF NOT [%SERVERNAME%] == [] SET RC=1 & echo serverName cannot be specified with clusterName. & GOTO PRINT_USAGE
GOTO SERVER_CLUSTER

REM Check for both server and node names as empty as this is for a stand-alone profile
:CHECKSERVER_EMPTY
IF [%SERVERNAME%]==[] GOTO SERVER_STANDALONE ELSE GOTO PRINT_USAGE

:PRINT_USAGE
ECHO.
ECHO  Usage: bootstrapProcessServerData.bat [-h(elp)] [-?] 
ECHO         [-nodeName ^<name^> -serverName ^<name^>] 
ECHO         [-clusterName ^<name^>]
ECHO. 
ECHO  Where:   
ECHO    -nodeName         - Optional node name. Must be specified with 
ECHO                        -serverName for a non-cluster server part of an 
ECHO             			ND environment. 
ECHO    -serverName       - Optional server name.  Must be specified with
ECHO                        -nodeName for a non-cluster server part of an 
ECHO             			ND environment.
ECHO    -clusterName       - Optional cluster name. Must be specified for a cluster
ECHO             			part of an ND environment.
ECHO.
ECHO  NOTE:  The parameters are case-sensitive. 
ECHO.       
ECHO.
ECHO  Example 1: bootstrap data into a non-cluster server part of an 
ECHO             ND environment
ECHO     bootstrapProcessServerData -nodeName node01 -serverName server1
ECHO.
ECHO  Example 2: bootstrap data into a cluster
ECHO     bootstrapProcessServerData -clusterName myAppCluster
ECHO.
ECHO  Example 3: bootstrap data into a stand-alone default profile server
ECHO     bootstrapProcessServerData
ECHO.
GOTO END

:CHECK_RESULT
IF %RC% EQU 0 ECHO The bootstrapping of data completed. Check the output for errors. & GOTO END
ECHO Errors occurred during the bootstrapping of data. & GOTO END

:END
echo RC=%RC%
exit /B %RC%
endlocal

:SERVER_CLUSTER
SET LOGFILE="%USER_INSTALL_ROOT%\logs\bootstrapProcesServerData.%CLUSTERNAME%.log"
echo Bootstrapping data into cluster %CLUSTERNAME% and logging into %LOGFILE%
call "%WAS_HOME%\bin\wsadmin" -lang jython -connType none -javaoption -Xmx1024m -tracefile "%LOGFILE%" -c "AdminTask.bootstrapProcessServerData(['-clusterName','%CLUSTERNAME%'])"
SET RC=%ERRORLEVEL%
GOTO END

:SERVER_SPECIFIC
SET LOGFILE="%USER_INSTALL_ROOT%\logs\bootstrapProcesServerData.%NODENAME%_%SERVERNAME%.log"
echo Bootstraping data into server %SERVERNAME% on node %NODENAME% and logging into %LOGFILE%
call "%WAS_HOME%\bin\wsadmin" -lang jython -connType none -javaoption -Xmx1024m -tracefile "%LOGFILE%" -c "AdminTask.bootstrapProcessServerData(['-nodeName','%NODENAME%','-serverName','%SERVERNAME%'])"
SET RC=%ERRORLEVEL%
GOTO END

:SERVER_STANDALONE
SET LOGFILE="%USER_INSTALL_ROOT%\logs\bootstrapProcesServerData.log"
echo Bootstraping data for server at %USER_INSTALL_ROOT% and logging into %LOGFILE% 
call "%WAS_HOME%\bin\wsadmin" -lang jython -connType none -javaoption -Xmx1024m -tracefile "%LOGFILE%" -c "AdminTask.bootstrapProcessServerData([])"
SET RC=%ERRORLEVEL%
GOTO END

:DO_DEFAULT_ACTION
SET LOGFILE="%USER_INSTALL_ROOT%\logs\bootstrapProcesServerData.log"
echo Bootstraping data for profile using default action at %USER_INSTALL_ROOT% and logging into %LOGFILE% 
call "%WAS_HOME%\bin\wsadmin" -lang jython -connType none -javaoption -Xmx1024m -tracefile "%LOGFILE%" -c "AdminTask.bootstrapProcessServerData(['-default', '%DEFAULT_ACTION%'])"
SET RC=%ERRORLEVEL%
GOTO END
